
use "$data\ENDUTIH_2018.dta", clear

*Uniquely and fully identifying ID variable
	isid upm viv_sel hogar num_ren

*Unit of observations

*____________________________Gender________________________________

*Female=1 Male=0
	g mujer=(sexo==2)
	label var mujer "1=Female"

*____________________________Age________________________________

	
*Age
	g age_0_6=(edad<7)
	g age_7_14=(edad>6 & edad<15)
	g age_15_19=(edad>14 & edad<20)
	g age_20_24=(edad>19 & edad<25)
	g age_25_29=(edad>24 & edad<30)
	g age_30_34=(edad>29 & edad<35)
	g age_35_39=(edad>34 & edad<40)
	g age_40_44=(edad>39 & edad<45)
	g age_45_49=(edad>44 & edad<50)
	g age_50_54=(edad>49 & edad<55)
	g age_55_59=(edad>54 & edad<60)
	g age_60_64=(edad>59 & edad<65)

	g age=.
	replace age=1 if age_20_24==1 & edad!=20 & edad!=21
	replace age=2 if age_25_29==1
	replace age=3 if age_30_34==1
	replace age=4 if age_35_39==1
	replace age=5 if age_40_44==1
	replace age=6 if age_45_49==1
	replace age=7 if age_50_54==1 | edad==55


	label define age 1 "20_24" 2 "25_29" 3 "30_34" 4 "35_39" 5 "40_44" 6 "45_49" 7 "50_54" 
	
	label values age age

*____________________________Urban/ Rural________________________________
	
*Zone Urban=0 Rural=1
	g zone=(dominio=="R") 
	label var zone "1=Rural"
	
*____________________________Education________________________________
	
*Education

*Middle School or less
	g edu_1=(nivel==2 | nivel==0 | nivel==1  ) if !missing(nivel) & nivel!=99

*High School
	g edu_2=(nivel==3 ) if !missing(nivel) & nivel!=99

*Certificate/Diploma
	g edu_3=(nivel==4 | nivel==5) if !missing(nivel) & nivel!=99

*College or more
	g edu_4=(nivel==6 | nivel==7 | nivel==8 |nivel==9 | nivel==10 | nivel==11) if nivel!=99

	
	g education=.
	replace education=1 if edu_1==1
	replace education=2 if edu_2==1
	replace education=3 if edu_3==1
	replace education=4 if edu_4==1

tab nivel if education==.,m

*____________________________Economic Status________________________________

*Economic status (estrato socioeconomico (ses))
*Low
	g ses_low=(estrato==1) 
*Middle low
	g ses_mlow=(estrato==2) 
*Middle high
	g ses_hlow=(estrato==3) 
*High
	g ses_high=(estrato==4) 


	gen ses=.
	replace ses=1 if ses_low==1
	replace ses=2 if ses_mlow==1
	replace ses=3 if ses_hlow==1
	replace ses=4 if ses_high==1


*___________________________Labor Force Participation________________________________
	

*Worked at least one hour 
*We do not consider I leave out: had a job but no work (2), looking for work (3), is retired or pensioned (4), he or she is studying (5) she or he is a person with some physical or mental limitation that prevents him from working (7) and those who did work but work without pay in a family business, she or he dedicates to household chores and/or the care of your children or another family member (6)

	g participation=(p3_10==1  ) if !missing(p3_10)
	replace participation=. if p3_10==7 | p3_10==3 | p3_10==4 | p3_10==5 | p3_10==2 | p3_12==6
	
*using verificacion de actividad  [does not work ]

	replace participation=1 if participation==0 & p3_11!=4  & !missing(p3_11)

*____________________________Partner/Married________________________________

	
	g aux_partnet_married=(paren==2)
	bys id_hogar: egen partner_married=max(aux_partnet_married)
	label var partner_married "1 if the person is married or has a partner"
	
	

*____________________________Elderly________________________________
	


*Presence of older or disability [SI]
	g person_elderly=(age>74 | p3_10==7)
	bys id_hogar: egen elderly=max(person_elderly)
	label var elderly "1 if the person is older than 75 or is disable"

	
*____________________________Number of Kids in the household________________________________
	
*under the age of 2
	g kids_under_2=(edad<3)
	bys id_hogar: egen hkids_under_2=max(kids_under_2)
	label var hkids_under_2 "1 if there are kids under the age of 2 in the household"

*between 3 and 6 
	g kids_3_6=(edad>2 & edad<7)
	bys id_hogar: egen hkids_3_6=max(kids_3_6)
	label var hkids_3_6 "1 if there are kids under are between 3 and 6 years old in the household"


*between 7 and 15
	g kids_7_15=(edad>6 & edad<16)
	bys id_hogar: egen hkids_7_15=max(kids_7_15)
	label var hkids_7_15 "1 if there are kids under are between 7 and 15 years old in the household"


*No minors in the household
	g no_kids=(hkids_under_2!=1 & hkids_3_6!=1 & hkids_7_15!=1 ) 
	label var no_kids "1 if there are no kids  in the household"


	gen n_kids=.
	replace n_kids=1 if no_kids==1
	replace n_kids=2 if hkids_under_2==1
	replace n_kids=3 if hkids_3_6==1
	replace n_kids=4 if hkids_7_15==1
	label var n_kids "kid's age in the household"

label define n_kids 1 "no kids" 2 "under 2" 3 "3 and 6" 4 "7 and 15" 


*____________________________Work Status_______________________________
*Work Status

* empleado, obrero o jornalero 
	g empleados=(p3_12==1 | p3_12==2  | p3_12==3) if participation==1
	label var empleados "salaried workers"

*self_empleados 
	g self_empleados=(p3_12==4) if participation==1
	label var self_empleados "self-employed workers"

 
*empleador
	g empleador=(p3_12==5) if participation==1
	label var empleador "employer workers"


*____________________________Year_______________________________

 
	g wave=2018
	label var wave "wave year"


*____________________________Restring Sample_______________________________

*filtro edad

	g filtro_edad=(edad>21 & edad<56)
	keep if filtro_edad==1

	keep if participation!=.

*education (does not know the level)
	drop if nivel==99


	sum   hkids_under_2 hkids_3_6  hkids_7_15  zone elderly partner_married edu_1 edu_2 edu_3 edu_4  age_20_24  age_25_29 age_30_34 age_35_39 age_40_44 age_45_49 ses_low ses_mlow ses_hlow 



*___________________________Dependent Variable ________________________________

 *Dependent Variable for the multinomial
	gen dependiente=.
	
 *does not participate in the labor force
	replace dependiente=1 if participation==0
	
 *Thise who participate in the labor force
 
  *employees but not working from home
  
	replace dependiente=2 if participation==1  
  
 *employed but do not work from home and are self-employed
 
	replace dependiente=3 if participation==1 & self_empleados==1

 *Employees have access to a computer and use it to work from home
 
 *p6_9_1: uso de la computadora para actividades laborales
 *p6_7_1: uso de la computadora en el hogar
 
	replace dependiente=4 if participation==1 & p6_9_1==1 & p6_7_1==1 
 
 *employees have access to a computer and use it to work from home and are self-employed
 
 *p6_9_1: uso de la computadora para actividades laborales
 *p6_7_1: uso de la computadora en el hogar
 
	replace dependiente=5 if participation==1 & p6_9_1==1 & p6_7_1==1 & self_empleados==1
	
	label define dependiente   1 "out of the labor force" 2 "on-site workers" 3 "on-site self-employed" 4 "teleworking" 5 "teleworking self-employed"



save "$data\ENDUTIH_2018_final.dta", replace


